Learn R Programming

roseRF (version 0.1.0)

unweighted_gplm: Unweighted (baseline) estimator for the generalised partially linear model

Description

Estimates the parameter of interest \(\theta_0\) in the generalised partially linear regression model $$g(\mathbb{E}[Y|X,Z]) = X\theta_0 + f_0(Z),$$ as in roseRF_gplm but without any weights i.e. \(J=1\), \(M_1(X)=X\) and \(w_1\equiv 1\).

Usage

unweighted_gplm(
  y_on_xz_formula,
  y_on_xz_learner,
  y_on_xz_pars = list(),
  Gy_on_z_formula,
  Gy_on_z_learner,
  Gy_on_z_pars = list(),
  x_formula,
  x_learner,
  x_pars = list(),
  link = "identity",
  data,
  K = 5,
  S = 1
)

Value

A list containing:

theta

The estimator of \(\theta_0\).

stderror

Huber robust estimate of the standard error of the \(\theta_0\)-estimator.

coefficients

Table of \(\theta_0\) coefficient estimator, standard error, z-value and p-value.

Arguments

y_on_xz_formula

a two-sided formula object describing the regression model for \(\mathbb{E}[Y|X,Z]\) (regressing \(Y\) on \((X,Z)\)).

y_on_xz_learner

a string specifying the regression method to fit the regression as given by y_on_xz_formula (e.g. randomforest, xgboost, neuralnet, gam).

y_on_xz_pars

a list containing hyperparameters for the y_on_xz_learner chosen. Default is an empty list, which performs hyperparameter tuning.

Gy_on_z_formula

a two-sided formula object describing the regression model for \(\mathbb{E}[g(\mathbb{E}[Y|X,Z])|Z]\) (regressing \(g(\hat{E}[Y|X,Z])\) on \(Z\)).

Gy_on_z_learner

a string specifying the regression method to fit the regression as given by Gy_on_z_formula (e.g. randomforest, xgboost, neuralnet, gam).

Gy_on_z_pars

a list containing hyperparameters for the Gy_on_z_learner chosen. Default is an empty list, which performs hyperparameter tuning.

x_formula

a two-sided formula object describing the regression model for \(\mathbb{E}[X|Z]\).

x_learner

a string specifying the regression method to fit the regression of \(X\) on \(Z\) as given by x_formula (e.g. randomforest, xgboost, neuralnet, gam).

x_pars

a list containing hyperparameters for the x_learner chosen. Default is an empty list, which performs hyperparameter tuning.

link

link function (\(g\)). Options include identity, log, sqrt, logit, probit. Default is identity.

data

a data frame containing the variables for the partially linear model.

K

the number of folds used for \(K\)-fold cross-fitting. Default is 5.

S

the number of repeats to mitigate the randomness in the estimator on the sample splits used for \(K\)-fold cross-fitting. Default is 5.