Estimates the parameter of interest \(\theta_0\) in the partially linear regression model
$$\mathbb{E}[Y|X,Z] = X\theta_0 + f_0(Z),$$ as in roseRF_plm but without
any weights i.e. \(J=1\), \(M_1(X)=X\) and \(w_1\equiv 1\).
unweighted_plm(
y_formula,
y_learner,
y_pars = list(),
x_formula,
x_learner,
x_pars = list(),
data,
K = 5,
S = 1
)A list containing:
thetaThe estimator of \(\theta_0\).
stderrorHuber robust estimate of the standard error of the \(\theta_0\)-estimator.
coefficientsTable of \(\theta_0\) coefficient estimator, standard error, z-value and p-value.
a two-sided formula object describing the regression model for \(\mathbb{E}[Y|Z]\).
a string specifying the regression method to fit the regression of \(Y\) on \(Z\) as given by y_formula (e.g. randomforest, xgboost, neuralnet, gam).
a list containing hyperparameters for the y_learner chosen. Default is an empty list, which performs hyperparameter tuning.
a two-sided formula object describing the regression model for \(\mathbb{E}[X|Z]\).
a string specifying the regression method to fit the regression of \(X\) on \(Z\) as given by x_formula (e.g. randomforest, xgboost, neuralnet, gam).
a list containing hyperparameters for the y_learner chosen. Default is an empty list, which performs hyperparameter tuning.
a data frame containing the variables for the partially linear model.
the number of folds used for \(K\)-fold cross-fitting. Default is 5.
the number of repeats to mitigate the randomness in the estimator on the sample splits used for \(K\)-fold cross-fitting. Default is 5.